@@ -186,7 +186,9 @@ class Model(ElementBase):
         elif sdf_version == "1.0":
             self._origin = origin
         else:
-            warnings.warn("`origin` is deprecated. Use `Model.pose` instead.")
+            warnings.warn(
+                "`origin` is deprecated. Use `Model.pose` instead.", DeprecationWarning
+            )
             self._origin = origin
 
         if len(links) == 0 and sdf_version in ["1.0", "1.2", "1.3", "1.4"]:
@@ -248,7 +250,8 @@ class Model(ElementBase):
     @property
     def origin(self):
         warnings.warn(
-            "`Model.origin` is deprecated since SDFormat v1.2. Use `Model.pose` instead."
+            "`Model.origin` is deprecated since SDFormat v1.2. Use `Model.pose` instead.",
+            DeprecationWarning,
         )
         return self._origin
 
